==> gurux_dlms-1.0.51.tar.gz: gurux_dlms-1.0.51/gurux_dlms/objects/enums/MBusEncryptionKeyStatus.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
#pylint: disable=broad-except,no-name-in-module
try:
    from enum import IntEnum
    __base = IntEnum
except Exception:
    __base = object

class MBusEncryptionKeyStatus(__base):
    """
    M-Bus encryption key status enumerated values.
    """
    #pylint: disable=too-few-public-methods

    NO_ENCRYPTION_KEY = 0
    ENCRYPTION_KEY_SET = 1
    ENCRYPTION_KEY_TRANSFERRED = 2
    ENCRYPTION_KEY_SET_AND_TRANSFERRED = 3
    ENCRYPTION_KEY_INUSE = 4

==> gurux_dlms-1.0.87.tar.gz: gurux_dlms-1.0.87/gurux_dlms/objects/enums/MBusEncryptionKeyStatus.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from gurux_dlms.GXIntEnum import GXIntEnum

class MBusEncryptionKeyStatus(GXIntEnum):
    """
    M-Bus encryption key status enumerated values.
    """
    #pylint: disable=too-few-public-methods

    NO_ENCRYPTION_KEY = 0
    ENCRYPTION_KEY_SET = 1
    ENCRYPTION_KEY_TRANSFERRED = 2
    ENCRYPTION_KEY_SET_AND_TRANSFERRED = 3
    ENCRYPTION_KEY_INUSE = 4
